==> haskell-hls-gadt-plugin-2.0.0.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-gadt-plugin-2.0.0.0-ALppV6KRKyQ8cbfFUvt8BM
key:                  hls-gadt-plugin-2.0.0.0-ALppV6KRKyQ8cbfFUvt8BM
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  d2878f59f4ad04dbbc2267b52a82557d
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.0.0.0-ALppV6KRKyQ8cbfFUvt8BM
depends:
    aeson-2.1.2.1-JtwfP0wSn8NCfmI6cbJvU2 base-4.17.2.1 containers-0.6.7
    extra-1.7.16-F5Rxe4JueYuCrnwKvJW3VT ghc-9.4.8 ghc-boot-th-9.4.8
    ghc-exactprint-1.6.1-G3x7yB2ZulKK6ktZMrFQh4
    ghcide-2.0.0.0-Bw55j8ivRdS1lZn7awmkvP
    hls-plugin-api-2.0.0.0-45nymQkyoUp6CHZYfB0y5r
    hls-refactor-plugin-2.0.0.0-GK1sQKj8kWUAlZQ6UVER6V
    lens-5.2.3-2UQe7k3aogFYCJ4tqsIcu lsp-1.6.0.0-AIlM1Pv3sP459C6JGeqr1z
    mtl-2.2.2 text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-gadt-plugin-2.0.0.0-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-gadt-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-gadt-plugin
version:              2.0.0.0
visibility:           public
id:                   hls-gadt-plugin-2.0.0.0-1kDSOwAB7VrFcctG3NGzhw
key:                  hls-gadt-plugin-2.0.0.0-1kDSOwAB7VrFcctG3NGzhw
license:              Apache-2.0
maintainer:           julytreee@gmail.com
author:               Lei Zhu
synopsis:             Convert to GADT syntax plugin
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server/tree/master/plugins/hls-gadt-plugin#readme>

category:             Development
abi:                  0494433e7bd8273277ffecc3867ea680
exposed:              True
exposed-modules:      Ide.Plugin.GADT
hidden-modules:       Ide.Plugin.GHC
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.0.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.0.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-gadt-plugin-2.0.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-gadt-plugin
hs-libraries:         HShls-gadt-plugin-2.0.0.0-1kDSOwAB7VrFcctG3NGzhw
depends:
    aeson-2.1.2.1-JtwfP0wSn8NCfmI6cbJvU2 base-4.17.2.1 containers-0.6.7
    extra-1.7.16-F5Rxe4JueYuCrnwKvJW3VT ghc-9.4.8 ghc-boot-th-9.4.8
    ghc-exactprint-1.6.1-G3x7yB2ZulKK6ktZMrFQh4
    ghcide-2.0.0.0-1gwnwbdcXosF15uYSqqK1D
    hls-plugin-api-2.0.0.0-45nymQkyoUp6CHZYfB0y5r
    hls-refactor-plugin-2.0.0.0-7763UDqcoLtCXX1yu2qo0o
    lens-5.2.3-2UQe7k3aogFYCJ4tqsIcu lsp-1.6.0.0-AIlM1Pv3sP459C6JGeqr1z
    mtl-2.2.2 text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-I6MqYi1ZitpKUe3ww5yyKM

haddock-interfaces:
    /usr/share/doc/haskell-hls-gadt-plugin/html/hls-gadt-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-gadt-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
